=== modified file 'examples/proxy.cc'
--- examples/proxy.cc	2011-11-26 23:14:59 +0000
+++ examples/proxy.cc	2011-11-27 01:25:57 +0000
@@ -54,9 +54,10 @@
   return; \
 }
 
-static void proxy(drizzle_st *drizzle, drizzle_con_st *server,
-                  drizzle_con_st *client, drizzle_result_st *server_result,
-                  drizzle_result_st *client_result, drizzle_column_st *column);
+static void proxy(drizzle_st *drizzle,
+                  drizzle_con_st *server,
+                  drizzle_con_st *client,
+                  drizzle_column_st *column);
 
 int main(int argc, char *argv[])
 {
@@ -71,7 +72,6 @@
   drizzle_verbose_t verbose= DRIZZLE_VERBOSE_NEVER;
   drizzle_return_t ret;
   drizzle_st *drizzle;
-  drizzle_result_st server_result;
   drizzle_result_st client_result;
   drizzle_column_st column;
 
@@ -207,7 +207,7 @@
       return 1;
     }
 
-    proxy(drizzle, server, client, &server_result, &client_result, &column);
+    proxy(drizzle, server, client, &column);
 
     drizzle_con_free(client);
     drizzle_con_free(server);
@@ -228,8 +228,8 @@
 }
 
 static void proxy(drizzle_st *drizzle, drizzle_con_st *server,
-                  drizzle_con_st *client, drizzle_result_st *server_result,
-                  drizzle_result_st *client_result, drizzle_column_st *column)
+                  drizzle_con_st *client,
+                  drizzle_column_st *column)
 {
   drizzle_return_t ret;
   drizzle_command_t command;
@@ -243,31 +243,34 @@
 
   /* Handshake packets. */
   ret= drizzle_handshake_server_read(client);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_server_read", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_server_read", drizzle);
 
   drizzle_con_copy_handshake(server, client);
 
   ret= drizzle_handshake_server_write(server);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_server_write", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_server_write", drizzle);
 
   ret= drizzle_handshake_client_read(server);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_read", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_read", drizzle);
 
   drizzle_con_copy_handshake(client, server);
 
   ret= drizzle_handshake_client_write(client);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_write", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_write", drizzle);
 
-  (void)drizzle_result_read(client, client_result, &ret);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_result_read", drizzle)
+  drizzle_result_st *client_result= drizzle_result_read(client, NULL, &ret);
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_result_read", drizzle);
 
   drizzle_con_set_status(server, drizzle_con_status(client));
 
-  if (drizzle_result_clone(server, server_result, client_result) == NULL)
-    DRIZZLE_RETURN_ERROR("drizzle_result_clone", drizzle)
+  drizzle_result_st *server_result;
+  if ((server_result= drizzle_result_clone(server, client_result)) == NULL)
+  {
+    DRIZZLE_RETURN_ERROR("drizzle_result_clone", drizzle);
+  }
 
   ret= drizzle_result_write(server, server_result, true);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
 
   if (drizzle_result_error_code(client_result) != 0 ||
       drizzle_result_eof(client_result))
@@ -286,51 +289,59 @@
 
     while (1)
     {
-      data= (uint8_t *)drizzle_con_command_read(server, &command, &offset, &size, &total,
-                                     &ret);
+      data= (uint8_t *)drizzle_con_command_read(server, &command, &offset, &size, &total, &ret);
       if (ret == DRIZZLE_RETURN_LOST_CONNECTION)
+      {
         return;
-
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_read", drizzle)
-
-      (void)drizzle_con_command_write(client, NULL, command, data, size, total,
-                                      &ret);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_write", drizzle)
+      }
+
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_read", drizzle);
+
+      (void)drizzle_con_command_write(client, NULL, command, data, size, total, &ret);
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_write", drizzle);
 
       if ((offset + size) == total)
         break;
     }
 
     if (command == DRIZZLE_COMMAND_QUIT)
+    {
       return;
+    }
     else if (command == DRIZZLE_COMMAND_FIELD_LIST)
     {
-      if (drizzle_result_create(client, client_result) == NULL)
+      if ((client_result= drizzle_result_create(client)) == NULL)
+      {
         DRIZZLE_RETURN_ERROR("drizzle_result_create", drizzle)
+      }
 
-      if (drizzle_result_create(server, server_result) == NULL)
-        DRIZZLE_RETURN_ERROR("drizzle_result_create", drizzle)
+      if ((server_result= drizzle_result_create(server)) == NULL)
+      {
+        DRIZZLE_RETURN_ERROR("drizzle_result_create", drizzle);
+      }
     }
     else
     {
       (void)drizzle_result_read(client, client_result, &ret);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_read", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_read", drizzle);
 
       drizzle_con_set_status(server, drizzle_con_status(client));
-      if (drizzle_result_clone(server, server_result, client_result) == NULL)
-        DRIZZLE_RETURN_ERROR("drizzle_result_clone", drizzle)
+      if ((server_result= drizzle_result_clone(server, client_result)) == NULL)
+      {
+        DRIZZLE_RETURN_ERROR("drizzle_result_clone", drizzle);
+      }
 
       if (drizzle_result_column_count(client_result) == 0)
       {
         /* Simple result with no column, row, or field data. */
         ret= drizzle_result_write(server, server_result, true);
-        DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+        DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
 
         continue;
       }
 
       ret= drizzle_result_write(server, server_result, false);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
     }
 
     /* Columns. */
@@ -338,14 +349,14 @@
     {
       if (drizzle_column_read(client_result, column, &ret) == NULL)
       {
-        DRIZZLE_RETURN_CHECK(ret, "drizzle_column_read", drizzle)
+        DRIZZLE_RETURN_CHECK(ret, "drizzle_column_read", drizzle);
         break;
       }
 
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_column_read", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_column_read", drizzle);
 
       ret= drizzle_column_write(server_result, column);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_column_write", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_column_write", drizzle);
 
       drizzle_column_free(column);
     }
@@ -356,20 +367,20 @@
     if (command == DRIZZLE_COMMAND_FIELD_LIST)
     {
       ret= drizzle_result_write(server, server_result, true);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
       continue;
     }
     else
     {
       ret= drizzle_result_write(server, server_result, false);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
     }
 
     /* Rows. */
     while (1)
     {
       row= drizzle_row_read(client_result, &ret);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_row_read", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_row_read", drizzle);
 
       if (row == 0)
         break;
@@ -378,7 +389,7 @@
                                   drizzle_result_row_size(client_result));
 
       ret= drizzle_row_write(server_result);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_row_write", drizzle)
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_row_write", drizzle);
 
       /* Fields. */
       row_break= false;
@@ -395,14 +406,16 @@
           row_break= true;
         }
         else
-          DRIZZLE_RETURN_CHECK(ret, "drizzle_field_read", drizzle)
+        {
+          DRIZZLE_RETURN_CHECK(ret, "drizzle_field_read", drizzle);
+        }
 
         ret= drizzle_field_write(server_result, field, size, total);
-        DRIZZLE_RETURN_CHECK(ret, "drizzle_field_write", drizzle)
+        DRIZZLE_RETURN_CHECK(ret, "drizzle_field_write", drizzle);
       }
     }
 
     ret= drizzle_result_write(server, server_result, true);
-    DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
+    DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle);
   }
 }

=== modified file 'examples/server.cc'
--- examples/server.cc	2011-11-26 23:14:59 +0000
+++ examples/server.cc	2011-11-27 01:25:57 +0000
@@ -58,8 +58,7 @@
   return; \
 }
 
-static void server(drizzle_st *drizzle, drizzle_con_st *con,
-                   drizzle_result_st *result, drizzle_column_st *column);
+static void server(drizzle_st *drizzle, drizzle_con_st *con, drizzle_column_st *column);
 
 int main(int argc, char *argv[])
 {
@@ -71,7 +70,6 @@
   drizzle_verbose_t verbose= DRIZZLE_VERBOSE_NEVER;
   drizzle_return_t ret;
   drizzle_st *drizzle;
-  drizzle_result_st result;
   drizzle_column_st column;
 
   while((c = getopt(argc, argv, "c:h:mp:v")) != -1)
@@ -169,7 +167,7 @@
       return 1;
     }
 
-    server(drizzle, con, &result, &column);
+    server(drizzle, con, &column);
 
     drizzle_con_free(con);
 
@@ -189,7 +187,7 @@
 }
 
 static void server(drizzle_st *drizzle, drizzle_con_st *con,
-                   drizzle_result_st *result, drizzle_column_st *column)
+                   drizzle_column_st *column)
 {
   drizzle_return_t ret;
   drizzle_command_t command;
@@ -218,10 +216,13 @@
   DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_server_write", drizzle)
 
   ret= drizzle_handshake_client_read(con);
-  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_read", drizzle)
+  DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_read", drizzle);
 
-  if (drizzle_result_create(con, result) == NULL)
+  drizzle_result_st *result;
+  if ((result= drizzle_result_create(con)) == NULL)
+  {
     DRIZZLE_RETURN_ERROR("drizzle_result_create", drizzle)
+  }
 
   ret= drizzle_result_write(con, result, true);
   DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", drizzle)
@@ -241,8 +242,10 @@
     }
     DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_buffer", drizzle)
 
-    if (drizzle_result_create(con, result) == NULL)
+    if ((result= drizzle_result_create(con)) == NULL)
+    {
       DRIZZLE_RETURN_ERROR("drizzle_result_create", drizzle)
+    }
 
     if (command != DRIZZLE_COMMAND_QUERY)
     {
@@ -258,7 +261,9 @@
 
     /* Columns. */
     if (drizzle_column_create(result, column) == NULL)
+    {
       DRIZZLE_RETURN_ERROR("drizzle_column_create", drizzle)
+    }
 
     drizzle_column_set_catalog(column, "default");
     drizzle_column_set_db(column, "drizzle_test_db");

=== modified file 'examples/simple_multi.cc'
--- examples/simple_multi.cc	2011-11-26 23:14:59 +0000
+++ examples/simple_multi.cc	2011-11-27 01:25:57 +0000
@@ -92,7 +92,7 @@
     }
 
     cons.push_back(con);
-    drizzle_result_st *res= drizzle_result_create(con, NULL);
+    drizzle_result_st *res= drizzle_result_create(con);
     result.push_back(res);
 
     drizzle_query_st *exec_query;

=== modified file 'examples/sqlite_server.cc'
--- examples/sqlite_server.cc	2011-11-26 23:14:59 +0000
+++ examples/sqlite_server.cc	2011-11-27 01:25:57 +0000
@@ -73,7 +73,7 @@
 {
   drizzle_st *drizzle;
   drizzle_con_st *con;
-  drizzle_result_st result;
+  drizzle_result_st *result;
   drizzle_column_st column;
   sqlite3* db;
   bool send_columns;
@@ -247,16 +247,18 @@
   ret= drizzle_handshake_client_read(server->con);
   DRIZZLE_RETURN_CHECK(ret, "drizzle_handshake_client_read", server->drizzle)
 
-  if (drizzle_result_create(server->con, &(server->result)) == NULL)
-    DRIZZLE_RETURN_ERROR("drizzle_result_create", server->drizzle)
+  if ((server->result= drizzle_result_create(server->con)) == NULL)
+  {
+    DRIZZLE_RETURN_ERROR("drizzle_result_create", server->drizzle);
+  }
 
-  ret= drizzle_result_write(server->con, &(server->result), true);
+  ret= drizzle_result_write(server->con, server->result, true);
   DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
 
   /* Command loop. */
   while (1)
   {
-    drizzle_result_free(&(server->result));
+    drizzle_result_free(server->result);
     free(data);
 
     data= (uint8_t *)drizzle_con_command_buffer(server->con, &command, &total, &ret);
@@ -266,7 +268,7 @@
       free(data);
       return;
     }
-    DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_buffer", server->drizzle)
+    DRIZZLE_RETURN_CHECK(ret, "drizzle_con_command_buffer", server->drizzle);
 
     if (server->verbose >= DRIZZLE_VERBOSE_INFO)
     {
@@ -274,20 +276,22 @@
              data == NULL ? "NULL" : (char *)data);
     }
 
-    if (drizzle_result_create(server->con, &(server->result)) == NULL)
-      DRIZZLE_RETURN_ERROR("drizzle_result_create", server->drizzle)
+    if ((server->result= drizzle_result_create(server->con)) == NULL)
+    {
+      DRIZZLE_RETURN_ERROR("drizzle_result_create", server->drizzle);
+    }
 
     if (command != DRIZZLE_COMMAND_QUERY ||
         !strcasecmp((char *)data, "SHOW DATABASES"))
     {
-      ret= drizzle_result_write(server->con, &(server->result), true);
-      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
+      ret= drizzle_result_write(server->con, server->result, true);
+      DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle);
 
       if (command == DRIZZLE_COMMAND_FIELD_LIST)
       {
-        drizzle_result_set_eof(&(server->result), true);
-        ret= drizzle_result_write(server->con, &(server->result), true);
-        DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
+        drizzle_result_set_eof(server->result, true);
+        ret= drizzle_result_write(server->con, server->result, true);
+        DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle);
       }
 
       continue;
@@ -325,9 +329,9 @@
       }
       else
       {
-        drizzle_result_set_error_code(&(server->result), (uint16_t)sqlite_ret);
-        drizzle_result_set_error(&(server->result), sqlite_err);
-        ret= drizzle_result_write(server->con, &(server->result), true);
+        drizzle_result_set_error_code(server->result, (uint16_t)sqlite_ret);
+        drizzle_result_set_error(server->result, sqlite_err);
+        ret= drizzle_result_write(server->con, server->result, true);
         DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
 
         fprintf(stderr, "sqlite3_exec:%s\n", sqlite_err);
@@ -339,14 +343,14 @@
 
     if (server->rows == 0)
     {
-      drizzle_result_set_column_count(&(server->result), 0);
-      ret= drizzle_result_write(server->con, &(server->result), true);
+      drizzle_result_set_column_count(server->result, 0);
+      ret= drizzle_result_write(server->con, server->result, true);
       DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
     }
     else
     {
-      drizzle_result_set_eof(&(server->result), true);
-      ret= drizzle_result_write(server->con, &(server->result), true);
+      drizzle_result_set_eof(server->result, true);
+      ret= drizzle_result_write(server->con, server->result, true);
       DRIZZLE_RETURN_CHECK(ret, "drizzle_result_write", server->drizzle)
     }
   }
@@ -362,12 +366,12 @@
   if (server->send_columns == true)
   {
     server->send_columns= false;
-    drizzle_result_set_column_count(&(server->result), (uint16_t)field_count);
+    drizzle_result_set_column_count(server->result, (uint16_t)field_count);
 
-    ret= drizzle_result_write(server->con, &(server->result), false);
+    ret= drizzle_result_write(server->con, server->result, false);
     DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_result_write", server->drizzle)
 
-    if (drizzle_column_create(&(server->result), &(server->column)) == NULL)
+    if (drizzle_column_create(server->result, &(server->column)) == NULL)
     {
       DRIZZLE_RETURN_CHECK_VAL(DRIZZLE_RETURN_MEMORY, "drizzle_column_create", server->drizzle)
     }
@@ -387,15 +391,15 @@
       drizzle_column_set_name(&(server->column), columns[x]);
       drizzle_column_set_orig_name(&(server->column), columns[x]);
 
-      ret= drizzle_column_write(&(server->result), &(server->column));
+      ret= drizzle_column_write(server->result, &(server->column));
       DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_column_write", server->drizzle)
     }
 
     drizzle_column_free(&(server->column));
 
-    drizzle_result_set_eof(&(server->result), true);
+    drizzle_result_set_eof(server->result, true);
 
-    ret= drizzle_result_write(server->con, &(server->result), false);
+    ret= drizzle_result_write(server->con, server->result, false);
     DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_result_write", server->drizzle)
   }
 
@@ -408,15 +412,15 @@
   }
 
   /* This is needed for MySQL and old Drizzle protocol. */
-  drizzle_result_calc_row_size(&(server->result), (drizzle_field_t *)fields,
+  drizzle_result_calc_row_size(server->result, (drizzle_field_t *)fields,
                                sizes);
 
-  ret= drizzle_row_write(&(server->result));
+  ret= drizzle_row_write(server->result);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_row_write", server->drizzle)
 
   for (x= 0; x < field_count; x++)
   {
-    ret= drizzle_field_write(&(server->result), (drizzle_field_t)fields[x],
+    ret= drizzle_field_write(server->result, (drizzle_field_t)fields[x],
                              sizes[x], sizes[x]);
     DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_field_write", server->drizzle)
   }
@@ -437,12 +441,12 @@
   fields[0]= (drizzle_field_t)SQLITE_SERVER_VERSION;
   sizes[0]= strlen(SQLITE_SERVER_VERSION);
 
-  drizzle_result_set_column_count(&(server->result), 1);
+  drizzle_result_set_column_count(server->result, 1);
 
-  ret= drizzle_result_write(server->con, &(server->result), false);
+  ret= drizzle_result_write(server->con, server->result, false);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_result_write", server->drizzle)
 
-  if (drizzle_column_create(&(server->result), &(server->column)) == NULL)
+  if (drizzle_column_create(server->result, &(server->column)) == NULL)
   {
     DRIZZLE_RETURN_CHECK_VAL(DRIZZLE_RETURN_MEMORY, "drizzle_column_create", server->drizzle)
   }
@@ -457,26 +461,26 @@
   drizzle_column_set_name(&(server->column), "version");
   drizzle_column_set_orig_name(&(server->column), "version");
 
-  ret= drizzle_column_write(&(server->result), &(server->column));
+  ret= drizzle_column_write(server->result, &(server->column));
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_column_write", server->drizzle)
 
   drizzle_column_free(&(server->column));
 
-  drizzle_result_set_eof(&(server->result), true);
+  drizzle_result_set_eof(server->result, true);
 
-  ret= drizzle_result_write(server->con, &(server->result), false);
+  ret= drizzle_result_write(server->con, server->result, false);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_result_write", server->drizzle)
 
   /* This is needed for MySQL and old Drizzle protocol. */
-  drizzle_result_calc_row_size(&(server->result), fields, sizes);
+  drizzle_result_calc_row_size(server->result, fields, sizes);
 
-  ret= drizzle_row_write(&(server->result));
+  ret= drizzle_row_write(server->result);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_row_write", server->drizzle)
 
-  ret= drizzle_field_write(&(server->result), fields[0], sizes[0], sizes[0]);
+  ret= drizzle_field_write(server->result, fields[0], sizes[0], sizes[0]);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_field_write", server->drizzle)
 
-  ret= drizzle_result_write(server->con, &(server->result), true);
+  ret= drizzle_result_write(server->con, server->result, true);
   DRIZZLE_RETURN_CHECK_VAL(ret, "drizzle_result_write", server->drizzle)
 
   return DRIZZLE_RETURN_OK;

=== modified file 'libdrizzle-2.0/conn.cc'
--- libdrizzle-2.0/conn.cc	2011-11-26 23:14:59 +0000
+++ libdrizzle-2.0/conn.cc	2011-11-27 01:25:57 +0000
@@ -638,7 +638,7 @@
         }
       }
 
-      con->result= drizzle_result_create(con, result);
+      con->result= drizzle_result_create_with(con, result);
       if (con->result == NULL)
       {
         *ret_ptr= DRIZZLE_RETURN_MEMORY;

=== modified file 'libdrizzle-2.0/handshake.cc'
--- libdrizzle-2.0/handshake.cc	2011-11-18 02:03:41 +0000
+++ libdrizzle-2.0/handshake.cc	2011-11-27 01:25:57 +0000
@@ -572,34 +572,36 @@
 
 drizzle_return_t drizzle_state_handshake_result_read(drizzle_con_st *con)
 {
-  drizzle_result_st result;
+  drizzle_result_st *result;
 
   drizzle_log_debug(con->drizzle, "drizzle_state_handshake_result_read");
 
-  if (drizzle_result_create(con, &result) == NULL)
+  if ((result= drizzle_result_create(con)) == NULL)
   {
     return DRIZZLE_RETURN_MEMORY;
   }
 
-  con->result= &result;
+  con->result= result;
 
   drizzle_return_t ret= drizzle_state_result_read(con);
   if (drizzle_state_none(con))
   {
     if (ret == DRIZZLE_RETURN_OK)
     {
-      if (drizzle_result_eof(&result))
+      if (drizzle_result_eof(result))
       {
         drizzle_set_error(con->drizzle, "drizzle_state_handshake_result_read",
                          "old insecure authentication mechanism not supported");
         ret= DRIZZLE_RETURN_AUTH_FAILED;
       }
       else
+      {
         con->options|= DRIZZLE_CON_READY;
+      }
     }
   }
 
-  drizzle_result_free(&result);
+  drizzle_result_free(result);
 
   if (ret == DRIZZLE_RETURN_ERROR_CODE)
   {

=== modified file 'libdrizzle-2.0/result.cc'
--- libdrizzle-2.0/result.cc	2011-11-21 00:54:34 +0000
+++ libdrizzle-2.0/result.cc	2011-11-27 01:25:57 +0000
@@ -46,8 +46,13 @@
  * Common definitions
  */
 
-drizzle_result_st *drizzle_result_create(drizzle_con_st *con,
-                                         drizzle_result_st *result)
+drizzle_result_st *drizzle_result_create(drizzle_con_st *con)
+{
+  return drizzle_result_create_with(con, NULL);
+}
+
+drizzle_result_st *drizzle_result_create_with(drizzle_con_st *con,
+                                              drizzle_result_st *result)
 {
   if (result == NULL)
   {
@@ -110,25 +115,24 @@
 }
 
 drizzle_result_st *drizzle_result_clone(drizzle_con_st *con,
-                                        drizzle_result_st *result,
-                                        drizzle_result_st *from)
+                                        drizzle_result_st *source)
 {
-  result= drizzle_result_create(con, result);
+  drizzle_result_st *result= drizzle_result_create(con);
   if (result == NULL)
   {
     return NULL;
   }
 
-  result->options= from->options;
+  result->options= source->options;
 
-  drizzle_result_set_info(result, from->info);
-  result->error_code= from->error_code;
-  drizzle_result_set_sqlstate(result, from->sqlstate);
-  result->warning_count= from->warning_count;
-  result->insert_id= from->insert_id;
-  result->affected_rows= from->affected_rows;
-  result->column_count= from->column_count;
-  result->row_count= from->row_count;
+  drizzle_result_set_info(result, source->info);
+  result->error_code= source->error_code;
+  drizzle_result_set_sqlstate(result, source->sqlstate);
+  result->warning_count= source->warning_count;
+  result->insert_id= source->insert_id;
+  result->affected_rows= source->affected_rows;
+  result->column_count= source->column_count;
+  result->row_count= source->row_count;
 
   return result;
 }
@@ -136,7 +140,6 @@
 void drizzle_result_free(drizzle_result_st *result)
 {
   drizzle_column_st *column;
-  uint64_t x;
 
   if (result == NULL)
   {
@@ -152,8 +155,10 @@
 
   if (result->options & DRIZZLE_RESULT_BUFFER_ROW)
   {
-    for (x= 0; x < result->row_count; x++)
-      drizzle_row_free(result, result->row_list->at(static_cast<size_t>(x)));
+    for (size_t x= 0; x < result->row_count; x++)
+    {
+      drizzle_row_free(result, result->row_list->at(x));
+    }
 
     delete result->row_list;
     delete result->field_sizes_list;
@@ -318,7 +323,7 @@
 
   if (drizzle_state_none(con))
   {
-    con->result= drizzle_result_create(con, result);
+    con->result= drizzle_result_create_with(con, result);
     if (con->result == NULL)
     {
       *ret_ptr= DRIZZLE_RETURN_MEMORY;

=== modified file 'libdrizzle-2.0/result.h'
--- libdrizzle-2.0/result.h	2011-11-07 15:04:16 +0000
+++ libdrizzle-2.0/result.h	2011-11-27 01:25:57 +0000
@@ -58,16 +58,17 @@
  * Initialize a result structure.
  */
 DRIZZLE_API
-drizzle_result_st *drizzle_result_create(drizzle_con_st *con,
-                                         drizzle_result_st *result);
+drizzle_result_st *drizzle_result_create(drizzle_con_st *con);
+
+drizzle_result_st *drizzle_result_create_with(drizzle_con_st *con,
+                                              drizzle_result_st *result);
 
 /**
  * Clone a connection structure.
  */
 DRIZZLE_API
-drizzle_result_st *drizzle_result_clone(drizzle_con_st *con,
-                                        drizzle_result_st *result,
-                                        drizzle_result_st *from);
+  drizzle_result_st *drizzle_result_clone(drizzle_con_st *con,
+                                          drizzle_result_st *source);
 
 /**
  * Free a result structure.

